@@ -1,13 +1,16 @@
 from .util import *
-import re
-
-csrf_regex = re.compile('<input type="hidden" name="_csrf" value="(.{36})">')
 
 
 class __THMAuth(object):
     def login(self, credentials):
-        initial = http_get(self.session, '/login', res_format='')
-        csrf_token = csrf_regex.search(initial).group(1)
+        """
+        Log in to THM
+
+        :param credentials: Login and password
+        :return: null
+        """
+
+        csrf_token = fetch_pattern(self.session, '/login', 'csrf-input')
 
         data = {
             'email': credentials['username'],
